@@ -23,13 +23,23 @@ from lib.common import APP_ICON, APPNAME
 
 class Notification:
 
+    def __init__(self):
+        self.notif = None
+
     def notify(self, title, message):
-        if pynotify.init(APPNAME):
-            n = pynotify.Notification(title, message)
-            n.set_urgency(pynotify.URGENCY_LOW)
-            pixbuf = gtk.gdk.pixbuf_new_from_file(APP_ICON)
-            n.set_icon_from_pixbuf(pixbuf)
-            n.set_timeout(pynotify.EXPIRES_DEFAULT)
-            n.show()
+
+        if self.notif == None:
+        
+            if pynotify.init(APPNAME):
+                self.notif = pynotify.Notification(title, message)
+                self.notif.set_urgency(pynotify.URGENCY_LOW)
+                pixbuf = gtk.gdk.pixbuf_new_from_file(APP_ICON)
+                self.notif.set_icon_from_pixbuf(pixbuf)
+                self.notif.set_timeout(pynotify.EXPIRES_DEFAULT)
+                self.notif.show()
+            else:
+                print "Error: there was a problem initializing the pynotify module"
+            
         else:
-            print "Error: there was a problem initializing the pynotify module"
+            self.notif.update(title, message)
+            self.notif.show()
